// =============================================================================
//
//      --- kvi_accel_qt.cpp ---
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#include "kvi_accel_qt.h"

KviAccel::KviAccel(QWidget *watch, QObject *parent, const char *psName)
	: QAccel(watch, parent, psName)
{
	// Nothing here
}

KviAccel::KviAccel(QWidget *parent, const char *name)
	: QAccel(parent, name)
{
	// Nothing here
}

KviAccel::~KviAccel()
{
	// Nothing here
}

const QKeySequence KviAccel::shortcut(const QString &action) const
{
	return QAccel::stringToKey(action);
}

#include "m_kvi_accel_qt.moc"
